@@ -15,7 +15,7 @@ logger = None
 
 class AppServer(Config):
     bool_options = ['debug', 'log_debug', 'auto_start_servers',
-        'get_public_ip']
+        'get_public_ip', 'inline_certs']
     int_options = ['port', 'session_timeout', 'key_bits', 'dh_param_bits']
     path_options = ['log_path', 'db_path', 'www_path', 'data_path',
         'server_cert_path', 'server_key_path']
@@ -23,6 +23,7 @@ class AppServer(Config):
     default_options = {
         'auto_start_servers': True,
         'get_public_ip': True,
+        'inline_certs': True,
         'session_timeout': DEFAULT_SESSION_TIMEOUT,
         'key_bits': DEFAULT_KEY_BITS,
         'dh_param_bits': DEFAULT_DH_PARAM_BITS,
@@ -115,8 +116,10 @@ class AppServer(Config):
         self.app_db = Database(self.db_path)
 
     def _close_db(self):
-        self.mem_db.close()
-        self.app_db.close()
+        if self.mem_db:
+            self.mem_db.close()
+        if self.app_db:
+            self.app_db.close()
 
     def _setup_handlers(self):
         import handlers
@@ -227,7 +230,12 @@ class AppServer(Config):
             self._server_cert_path, self._server_key_path)
         try:
             server.start()
-        except (KeyboardInterrupt, SystemExit), exc:
+        except (KeyboardInterrupt, SystemExit):
+            pass
+        except:
+            logger.exception('Server error occurred')
+            raise
+        finally:
             signal.signal(signal.SIGINT, signal.SIG_IGN)
             LogEntry(message='Web server stopped.')
             self.interrupt = True
@@ -246,6 +254,11 @@ class AppServer(Config):
 
         try:
             self.app.run(host=self.bind_addr, port=self.port, threaded=True)
+        except (KeyboardInterrupt, SystemExit):
+            pass
+        except:
+            logger.exception('Server error occurred')
+            raise
         finally:
             signal.signal(signal.SIGINT, signal.SIG_IGN)
             LogEntry(message='Web server stopped.')
@@ -263,9 +276,8 @@ class AppServer(Config):
             self._run_wsgi()
 
     def run_server(self):
-        self._setup_all()
-        self._run_server()
-
-    def run_all(self):
-        self._setup_all()
-        self._run_server()
+        try:
+            self._setup_all()
+            self._run_server()
+        finally:
+            self._close_db()
