@@ -39,6 +39,7 @@ CERTS_DIR = 'certs'
 USERS_DIR = 'users'
 INDEXED_CERTS_DIR = 'indexed_certs'
 TEMP_DIR = 'temp'
+EMPTY_TEMP_DIR = 'empty_temp'
 INDEX_NAME = 'index'
 SERIAL_NAME = 'serial'
 CRL_NAME = 'ca.crl'
@@ -183,10 +184,11 @@ PORT_PROTOCOL_IN_USE = 'port_protocol_in_use'
 PORT_PROTOCOL_IN_USE_MSG = 'Port and protocol is already in use.'
 
 SERVER_NOT_OFFLINE = 'server_not_offline'
-SERVER_NOT_OFFLINE_MSG = 'Server must be offline to modify settings.'
-
-SERVER_ADD_ORG_RUNNING = 'server_add_org_running'
-SERVER_NOT_OFFLINE_MSG = 'Server must be offline to attached an organization.'
+SERVER_NOT_OFFLINE_SETTINGS_MSG = 'Server must be offline to modify settings.'
+SERVER_NOT_OFFLINE_ATTACH_ORG_MSG = 'Server must be offline to attach ' + \
+    'an organization.'
+SERVER_NOT_OFFLINE_DETACH_ORG_MSG = 'Server must be offline to detach ' + \
+    'an organization.'
 
 OVPN_SERVER_CONF = """port %s
 proto %s
@@ -317,6 +319,11 @@ if not org or not common_name:
 # Get username and password from input file
 with open(sys.argv[1], 'r') as auth_file:
     username, password = [x.strip() for x in auth_file.readlines()[:2]]
+password = password[:6]
+if not password.isdigit():
+    log_write('[ORG=%%s][UID=%%s][FAILED] Authenticator code is invalid' %% (
+        org, common_name))
+    raise TypeError('Authenticator code is invalid')
 
 # Get secretkey from user conf
 secretkey = None
