@@ -12,6 +12,7 @@ import shutil
 import subprocess
 import threading
 import logging
+import traceback
 
 logger = logging.getLogger(APP_NAME)
 _threads = {}
@@ -23,13 +24,13 @@ class Server(Config):
     str_options = ['name', 'network', 'interface', 'protocol',
         'local_network', 'public_address', 'primary_organization',
         'primary_user', 'organizations']
-    bool_options = ['debug']
+    bool_options = ['otp_auth', 'lzo_compression', 'debug']
     int_options = ['port']
     list_options = ['organizations']
 
     def __init__(self, id=None, name=None, network=None, interface=None,
             port=None, protocol=None, local_network=None, public_address=None,
-            debug=None, organizations=[]):
+            otp_auth=None, lzo_compression=None, debug=None, organizations=[]):
         Config.__init__(self)
         self._cur_event = None
         self._last_event = 0
@@ -44,20 +45,23 @@ class Server(Config):
             self.protocol = protocol
             self.local_network = local_network
             self.public_address = public_address
+            self.otp_auth = otp_auth
+            self.lzo_compression = lzo_compression
             self.debug = debug
             self.organizations = organizations
         else:
             self._initialized = True
             self.id = id
 
-        data_path = app_server.data_path or DEFAULT_DATA_PATH
-        self.path = os.path.join(data_path, SERVERS_DIR, self.id)
+        self.path = os.path.join(app_server.data_path, SERVERS_DIR, self.id)
         self.ovpn_conf_path = os.path.join(self.path, TEMP_DIR, OVPN_CONF_NAME)
         self.dh_param_path = os.path.join(self.path, DH_PARAM_NAME)
         self.ifc_pool_path = os.path.join(self.path, IFC_POOL_NAME)
         self.ca_cert_path = os.path.join(self.path, TEMP_DIR, OVPN_CA_NAME)
         self.tls_verify_path = os.path.join(self.path, TEMP_DIR,
             TLS_VERIFY_NAME)
+        self.user_pass_verify_path = os.path.join(self.path, TEMP_DIR,
+            USER_PASS_VERIFY_NAME)
         self.ovpn_status_path = os.path.join(self.path, TEMP_DIR,
             OVPN_STATUS_NAME)
         self.set_path(os.path.join(self.path, 'server.conf'))
@@ -115,6 +119,15 @@ class Server(Config):
         logger.info('Removing server. %r' % {
             'server_id': self.id,
         })
+        if self.status:
+            self.force_stop()
+            for i in xrange(20):
+                if not self.status:
+                    break
+                time.sleep(0.1)
+            if self.status:
+                self.force_stop()
+                time.sleep(0.5)
         self._remove_primary_user()
         shutil.rmtree(self.path)
         LogEntry(message='Deleted server.')
@@ -224,7 +237,7 @@ class Server(Config):
         args = [
             'openssl', 'dhparam',
             '-out', self.dh_param_path,
-            str(app_server.dh_param_bits or DEFAULT_DH_PARAM_BITS)
+            str(app_server.dh_param_bits)
         ]
         subprocess.check_call(args, stdout=subprocess.PIPE,
             stderr=subprocess.PIPE)
@@ -253,13 +266,31 @@ class Server(Config):
             'server_id': self.id,
         })
         with open(self.tls_verify_path, 'w') as tls_verify_file:
-            data_path = app_server.data_path or DEFAULT_DATA_PATH
+            data_path = app_server.data_path
             tls_verify_file.write(TLS_VERIFY_SCRIPT % (
+                data_path,
+                ORGS_DIR,
+                AUTH_LOG_NAME,
                 INDEX_NAME,
-                os.path.join(data_path, ORGS_DIR),
             ))
         os.chmod(self.tls_verify_path, 0755)
 
+    def _generate_user_pass_verify(self):
+        logger.debug('Generating user pass verify script. %r' % {
+            'server_id': self.id,
+        })
+        with open(self.user_pass_verify_path, 'w') as user_pass_verify_file:
+            data_path = app_server.data_path
+            user_pass_verify_file.write(USER_PASS_VERIFY_SCRIPT % (
+                data_path,
+                ORGS_DIR,
+                USERS_DIR,
+                TEMP_DIR,
+                AUTH_LOG_NAME,
+                OTP_JSON_NAME,
+            ))
+        os.chmod(self.user_pass_verify_path, 0755)
+
     def _generate_ovpn_conf(self):
         if not self.get_orgs():
             raise ValueError('Ovpn conf cannot be generated without ' + \
@@ -280,6 +311,7 @@ class Server(Config):
 
         self.generate_ca_cert()
         self._generate_tls_verify()
+        self._generate_user_pass_verify()
 
         if self.local_network:
             push = 'route %s %s' % self._parse_network(
@@ -287,23 +319,35 @@ class Server(Config):
         else:
             push = 'redirect-gateway'
 
+        server_conf = OVPN_SERVER_CONF % (
+            self.port,
+            self.protocol,
+            self.interface,
+            self.ca_cert_path,
+            primary_user.cert_path,
+            primary_user.key_path,
+            self.tls_verify_path,
+            self.dh_param_path,
+            '%s %s' % self._parse_network(self.network),
+            self.ifc_pool_path,
+            push,
+            self.ovpn_status_path,
+            4 if self.debug else 1,
+            8 if self.debug else 3,
+        )
+
+        if self.otp_auth:
+            server_conf += 'auth-user-pass-verify %s via-file\n' % (
+                self.user_pass_verify_path)
+
+        if self.lzo_compression:
+            server_conf += 'comp-lzo\npush "comp-lzo"\n'
+
+        if self.local_network:
+            server_conf += 'client-to-client\n'
+
         with open(self.ovpn_conf_path, 'w') as ovpn_conf:
-            ovpn_conf.write(OVPN_SERVER_CONF % (
-                self.port,
-                self.protocol,
-                self.interface,
-                self.ca_cert_path,
-                primary_user.cert_path,
-                primary_user.key_path,
-                self.tls_verify_path,
-                self.dh_param_path,
-                '%s %s' % self._parse_network(self.network),
-                self.ifc_pool_path,
-                push,
-                self.ovpn_status_path,
-                4 if self.debug else 1,
-                8 if self.debug else 3,
-            ))
+            ovpn_conf.write(server_conf)
 
     def _enable_ip_forwarding(self):
         try:
@@ -446,6 +490,9 @@ class Server(Config):
                     stdout=subprocess.PIPE, stderr=subprocess.PIPE)
                 _process[self.id] = process
             except OSError:
+                _output[self.id] += traceback.format_exc()
+                self._event_delay(type=SERVER_OUTPUT_UPDATED,
+                    resource_id=self.id)
                 logger.exception('Failed to start ovpn process. %r' % {
                     'server_id': self.id,
                 })
@@ -479,6 +526,8 @@ class Server(Config):
             Event(type=SERVERS_UPDATED)
 
     def start(self):
+        if self.status:
+            return
         if not self.get_orgs():
             raise ValueError('Server cannot be started without ' + \
                 'any organizations')
@@ -498,16 +547,25 @@ class Server(Config):
 
     def stop(self):
         if not self.status:
-            raise ValueError('Server is not running')
+            return
         logger.debug('Stopping server. %r' % {
             'server_id': self.id,
         })
         _process[self.id].send_signal(signal.SIGINT)
         LogEntry(message='Stopped server "%s".' % self.name)
 
+    def force_stop(self):
+        if not self.status:
+            return
+        logger.info('Forcing stop server. %r' % {
+            'server_id': self.id,
+        })
+        _process[self.id].send_signal(signal.SIGKILL)
+        LogEntry(message='Stopped server "%s".' % self.name)
+
     def restart(self):
         if not self.status:
-            raise ValueError('Server is not running')
+            self.start()
         logger.debug('Restarting server. %r' % {
             'server_id': self.id,
         })
@@ -517,7 +575,7 @@ class Server(Config):
 
     def reload(self):
         if not self.status:
-            raise ValueError('Server is not running')
+            self.start()
         logger.debug('Reloading server. %r' % {
             'server_id': self.id,
         })
@@ -546,7 +604,7 @@ class Server(Config):
                 for line in status_file.readlines():
                     if line[:11] != 'CLIENT_LIST':
                         continue
-                    line_split = line.split(',')
+                    line_split = line.strip('\n').split(',')
                     client_id = line_split[1]
                     real_address = line_split[2]
                     virt_address = line_split[3]
@@ -566,7 +624,7 @@ class Server(Config):
     @staticmethod
     def get_servers():
         logger.debug('Getting servers.')
-        data_path = app_server.data_path or DEFAULT_DATA_PATH
+        data_path = app_server.data_path
         path = os.path.join(data_path, SERVERS_DIR)
         servers = []
         if os.path.isdir(path):
