@@ -18,6 +18,8 @@ define([
       'protocol': null,
       'local_network': null,
       'public_address': null,
+      'otp_auth': null,
+      'lzo_compression': null,
       'debug': null
     },
     url: function() {
